@@ -9,7 +9,7 @@ All that matters is that, it is debugged and works appropriately! ;-)
 
 import sys
 from friendly_traceback.base_formatters import select_items, no_result, repl_indentation
-from ..utils import get_highlighting_ranges
+from friendly_traceback.utils import get_highlighting_ranges
 
 if sys.version_info >= (3, 9, 5):
     repl_indentation["suggest"] = "single"  # more appropriate value
