@@ -11,6 +11,7 @@ old_set_lang = set_lang  # noqa
 from friendly.my_gettext import current_lang
 from friendly import set_lang, _print_settings
 from friendly.settings import _remove_environment
+from friendly.theme import colours
 
 # The following is different from the one imported via the import * above
 from friendly import set_formatter
@@ -63,11 +64,20 @@ def plain():
     set_formatter("plain")
 
 
-def set_background(color):
+def set_background(color=None):
     """Sets the background color for the current environment."""
+    if color is None:
+        colours.set_background_color(None)
+        return
     set_formatter(background=color)
 
 
+def set_highlight(bg="#cc0000", fg="white"):
+    """Sets the highlight colour. Use None to turn off highlight."""
+    # Need to validate colour if not None, and revert to default
+    colours.set_highlight(bg=bg, fg=fg)
+
+
 def set_width(width=80):
     """Sets the width in a iPython/Jupyter session using a Rich formatter."""
     try:
@@ -75,12 +85,10 @@ def set_width(width=80):
     except Exception:  # noqa
         return
     session.rich_width = width
-    if session.is_jupyter:
-        if (
-            session.rich_tb_width is not None
-            and session.rich_width > session.rich_tb_width
-        ):
-            session.rich_tb_width = width
+    if session.is_jupyter and (
+        session.rich_tb_width is not None and session.rich_width > session.rich_tb_width
+    ):
+        session.rich_tb_width = width
 
 
 short_description["dark"] = lambda: _(
@@ -91,6 +99,7 @@ short_description["light"] = lambda: _(
 )
 short_description["plain"] = lambda: _("Plain formatting, with no colours added.")
 short_description["set_background"] = lambda: _("Sets the background color.")
+short_description["set_highlight"] = lambda: _("Sets the highlight colors; bg and fg.")
 short_description["set_width"] = lambda: _("Sets the output width in some modes.")
 short_description["_print_settings"] = lambda: _("Prints the saved settings.")
 short_description["_remove_environment"] = lambda: (
@@ -102,6 +111,7 @@ local_helpers = {
     "plain": plain,
     "set_width": set_width,
     "set_background": set_background,
+    "set_highlight": set_highlight,
     "_print_settings": _print_settings,
     "_remove_environment": _remove_environment,
 }
